@@ -1,10 +1,11 @@
 from .Accordion import Accordion
 from .AccordionItem import AccordionItem
+from .ActionIcon import ActionIcon
 from .Affix import Affix
 from .Alert import Alert
 from .Anchor import Anchor
 from .Avatar import Avatar
-from .AvatarGroup import AvatarGroup
+from .AvatarsGroup import AvatarsGroup
 from .BackgroundImage import BackgroundImage
 from .Badge import Badge
 from .Blockquote import Blockquote
@@ -19,6 +20,7 @@ from .ColorPicker import ColorPicker
 from .Container import Container
 from .DatePicker import DatePicker
 from .DateRangePicker import DateRangePicker
+from .DemoSlider import DemoSlider
 from .Divider import Divider
 from .Drawer import Drawer
 from .Grid import Grid
@@ -65,6 +67,7 @@ from .Tabs import Tabs
 from .Text import Text
 from .TextInput import TextInput
 from .ThemeIcon import ThemeIcon
+from .ThemeSwitcher import ThemeSwitcher
 from .TimeInput import TimeInput
 from .Timeline import Timeline
 from .TimelineItem import TimelineItem
@@ -74,11 +77,12 @@ from .Tooltip import Tooltip
 __all__ = [
     "Accordion",
     "AccordionItem",
+    "ActionIcon",
     "Affix",
     "Alert",
     "Anchor",
     "Avatar",
-    "AvatarGroup",
+    "AvatarsGroup",
     "BackgroundImage",
     "Badge",
     "Blockquote",
@@ -93,6 +97,7 @@ __all__ = [
     "Container",
     "DatePicker",
     "DateRangePicker",
+    "DemoSlider",
     "Divider",
     "Drawer",
     "Grid",
@@ -139,6 +144,7 @@ __all__ = [
     "Text",
     "TextInput",
     "ThemeIcon",
+    "ThemeSwitcher",
     "TimeInput",
     "Timeline",
     "TimelineItem",
